@@ -30,8 +30,9 @@ class LocalMetadata():
             if "MPI" in func or "H5" in func: continue
 
             if "dir" in func: continue
-            if "open" in func or "close" in func or "creat" in func:
-                self.filemap.add( r.args[0] )
+            if "open" in func or "close" in func or "creat" in func \
+                or "seek" in func or "sync" in func:
+                self.filemap.add(r.args[0] if type(r.args[0])==str else r.args[i].decode('utf-8'))
 
         self.num_files = len(self.filemap)
 
@@ -95,7 +96,7 @@ class RecorderReader:
         for rank in range(self.GM.total_ranks):
             LM = LocalMetadata(self.funcs, self.records[rank], counts[rank])
             self.LMs.append(LM)
-            print("Rank: %d, calls: %d, files: %d" %(rank, counts[rank], LM.num_files))
+            print("Rank: %d, intercepted calls: %d, accessed files: %d" %(rank, counts[rank], LM.num_files))
 
     def load_func_list(self, global_metadata_path):
         with open(global_metadata_path, 'rb') as f:
